@@ -24,8 +24,18 @@ class _Encoder(json.JSONEncoder):
             return obj.name
         elif isinstance(obj, TriggerColliderShape):
             return obj.name
-        elif isinstance(obj, BoxContainer) or isinstance(obj, SphereContainer) or isinstance(obj, CylinderContainer):
-            return obj.__dict__
+        elif isinstance(obj, BoxContainer):
+            c = {"shape": TriggerColliderShape.box.name}
+            c.update(obj.__dict__)
+            return c
+        elif isinstance(obj, SphereContainer):
+            c = {"shape": TriggerColliderShape.sphere.name}
+            c.update(obj.__dict__)
+            return c
+        elif isinstance(obj, CylinderContainer):
+            c = {"shape": TriggerColliderShape.cylinder.name}
+            c.update(obj.__dict__)
+            return c
         elif isinstance(obj, Room):
             return obj.__dict__
         elif isinstance(obj, InteriorRegion):
