@@ -1,3 +1,5 @@
+from json import loads
+from pkg_resources import resource_filename
 import numpy as np
 import random
 import math
@@ -13,6 +15,8 @@ from tdw.controller import Controller
 from typing import List, Tuple, Dict, Optional, Union
 from tdw.librarian import ModelRecord, ModelLibrarian, SceneLibrarian, MaterialLibrarian, HDRISkyboxLibrarian, \
     RobotLibrarian, HumanoidLibrarian, HumanoidAnimationLibrarian
+from tdw.cardinal_direction import CardinalDirection
+from tdw.ordinal_direction import OrdinalDirection
 from pathlib import Path
 import boto3
 from botocore.exceptions import ProfileNotFound, ClientError
@@ -913,3 +917,53 @@ class TDWUtils:
                 raise Exception(library_path)
             library = librarian_type(path)
             library_dictionary[library.get_default_library()] = library
+
+    @staticmethod
+    def get_corners_from_wall(wall: CardinalDirection) -> List[OrdinalDirection]:
+        """
+        :param wall: The wall as a [`CardinalDirection`](cardinal_direction.md).
+
+        :return: The corners of the wall as a 2-element list of [`OrdinalDirection`](ordinal_direction.md).
+        """
+
+        if wall == CardinalDirection.north:
+            return [OrdinalDirection.northwest, OrdinalDirection.northeast]
+        elif wall == CardinalDirection.south:
+            return [OrdinalDirection.southwest, OrdinalDirection.southeast]
+        elif wall == CardinalDirection.west:
+            return [OrdinalDirection.northwest, OrdinalDirection.southwest]
+        elif wall == CardinalDirection.east:
+            return [OrdinalDirection.northeast, OrdinalDirection.southeast]
+
+    @staticmethod
+    def get_direction_from_corner(corner: OrdinalDirection, wall: CardinalDirection) -> CardinalDirection:
+        """
+        Given an corner an a wall, get the direction that a lateral arrangement will run along.
+
+        :param corner: The corner as an [`OrdinalDirection`](ordinal_direction.md).
+        :param wall: The wall as a [`CardinalDirection`](cardinal_direction.md).
+
+        :return: Tuple: direction, wall
+        """
+
+        if corner == OrdinalDirection.northwest:
+            if wall == CardinalDirection.north:
+                return CardinalDirection.east
+            elif wall == CardinalDirection.west:
+                return CardinalDirection.south
+        elif corner == OrdinalDirection.northeast:
+            if wall == CardinalDirection.north:
+                return CardinalDirection.west
+            elif wall == CardinalDirection.east:
+                return CardinalDirection.south
+        elif corner == OrdinalDirection.southwest:
+            if wall == CardinalDirection.south:
+                return CardinalDirection.east
+            elif wall == CardinalDirection.west:
+                return CardinalDirection.north
+        elif corner == OrdinalDirection.southeast:
+            if wall == CardinalDirection.south:
+                return CardinalDirection.west
+            elif wall == CardinalDirection.east:
+                return CardinalDirection.north
+        raise Exception(corner, wall)
